@@ -197,7 +197,7 @@
 	(org-capture-kill))
       (buffer-string)))))
 
-(ert-deftest test-org-caputre/entry ()
+(ert-deftest test-org-capture/entry ()
   "Test `entry' type in capture template."
   ;; Do not break next headline.
   (should
@@ -208,7 +208,6 @@
 	     (org-capture-templates
 	      `(("t" "Todo" entry (file+headline ,file "A") "** H1 %?"))))
 	(org-capture nil "t")
-	(goto-char (point-max))
 	(insert "Capture text")
 	(org-capture-finalize))
       (buffer-string))))
@@ -232,7 +231,29 @@
 	     `(("t" "Test" entry (file+headline ,file "A") "** "
 		:immediate-finish t))))
        (org-capture nil "t")
-       (buffer-string)))))
+       (buffer-string))))
+  ;; With a 0 prefix argument, ignore surrounding lists.
+  (should
+   (equal "Foo\n* X\nBar\n"
+	  (org-test-with-temp-text-in-file "Foo\nBar"
+	    (forward-line)
+	    (let* ((file (buffer-file-name))
+		   (org-capture-templates
+		    `(("t" "Test" entry (file ,file) "* X"
+		       :immediate-finish t))))
+	      (org-capture 0 "t")
+	      (buffer-string)))))
+  ;; With a 0 prefix argument, also obey to :empty-lines.
+  (should
+   (equal "Foo\n\n* X\n\nBar\n"
+	  (org-test-with-temp-text-in-file "Foo\nBar"
+	    (forward-line)
+	    (let* ((file (buffer-file-name))
+		   (org-capture-templates
+		    `(("t" "Test" entry (file ,file) "* X"
+		       :immediate-finish t :empty-lines 1))))
+	      (org-capture 0 "t")
+	      (buffer-string))))))
 
 (ert-deftest test-org-capture/item ()
   "Test `item' type in capture template."
@@ -450,7 +471,27 @@
 	(goto-char (point-max))
 	(insert "Foo")
 	(org-capture-finalize))
-      (buffer-string)))))
+      (buffer-string))))
+  ;; With a 0 prefix argument, ignore surrounding lists.
+  (should
+   (equal "- X\nFoo\n\n- A\n"
+	  (org-test-with-temp-text-in-file "Foo\n\n- A"
+	    (let* ((file (buffer-file-name))
+		   (org-capture-templates
+		    `(("t" "Test" item (file ,file) "- X"
+		       :immediate-finish t))))
+	      (org-capture 0 "t")
+	      (buffer-string)))))
+  ;; With a 0 prefix argument, also obey to `:empty-lines'.
+  (should
+   (equal "\n- X\n\nFoo\n\n- A\n"
+	  (org-test-with-temp-text-in-file "Foo\n\n- A"
+	    (let* ((file (buffer-file-name))
+		   (org-capture-templates
+		    `(("t" "Test" item (file ,file) "- X"
+		       :immediate-finish t :empty-lines 1))))
+	      (org-capture 0 "t")
+	      (buffer-string))))))
 
 (ert-deftest test-org-capture/table-line ()
   "Test `table-line' type in capture template."
@@ -625,7 +666,17 @@
 	      `(("t" "Table" table-line (file ,file)
 		 "| 2 |" :immediate-finish t))))
 	(org-capture nil "t")
-	(org-table-get-stored-formulas))))))
+	(org-table-get-stored-formulas)))))
+  ;; With a 0 prefix argument, ignore surrounding tables.
+  (should
+   (equal "|   |\n|---|\n| B |\nFoo\n\n| A |\n"
+	  (org-test-with-temp-text-in-file "Foo\n\n| A |"
+	    (let* ((file (buffer-file-name))
+		   (org-capture-templates
+		    `(("t" "Test" table-line (file ,file) "| B |"
+		       :immediate-finish t))))
+	      (org-capture 0 "t")
+	      (buffer-string))))))
 
 (ert-deftest test-org-capture/plain ()
   "Test `plain' type in capture template."
